@@ -13,6 +13,10 @@ from clu.exporting import Exporter
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
+# OS UTILITIES: get the current users’ home directory
+
+gethomedir = lambda: os.path.expanduser("~")
+
 @export
 def wrap_value(value):
     """ Get a “lazified” copy of a value, wrapped in a lamba """
@@ -52,11 +56,50 @@ def stringify(instance, fields):
     return f"{typename}({field_dict_string}) @ {hex_id}"
 
 ex = os.path.extsep
+dolla = '$'
+
+@lru_cache(maxsize=32)
+def re_matcher(string):
+    """ Return a boolean function that will search for the given
+        regular-expression within any strings with which it is called,
+        returning True when the regex matches from the beginning of the
+        string, and False when it doesn’t.
+    """
+    if not string:
+        return true_function
+    match_function = re.compile(string, re.IGNORECASE).match
+    return lambda searching: bool(match_function(searching))
+
+@lru_cache(maxsize=32)
+def re_searcher(string):
+    """ Return a boolean function that will search for the given
+        regular-expression within any strings with which it is called,
+        returning True when the regex matches and False when it doesn’t.
+        
+        Useful in filter(…) calls and comprehensions, e.g.:
+        
+        >>> plists = filter(re_searcher(r'.plist$'), os.listdir())
+        >>> mmsuffix = suffix_searcher(r'.mm$')
+        >>> objcpp = (f for f in os.listdir() where mmsuffix(f))
+    """
+    if not string:
+        return true_function
+    search_function = re.compile(string, re.IGNORECASE).search
+    return lambda searching: bool(search_function(searching))
 
 @export
-def suffix_searcher(suffix):
+def re_suffix(string):
+    """ Remove any “os.path.extsep” prefixing a string and ensure
+        it ends with a “$” – to indicate a regular expression suffix.
+    """
+    if string is None:
+        return None
+    return rf"{string.lower().lstrip(ex).rstrip(dolla)}$"
+
+@export
+def suffix_searcher(string):
     """ Return a boolean function that will search for the given
-        file suffix in strings with which it is called, returning
+        string within any strings with which it is called, returning
         True when they are found and False when they aren’t.
         
         Useful in filter(…) calls and comprehensions, e.g.:
@@ -65,11 +108,7 @@ def suffix_searcher(suffix):
         >>> mmsuffix = suffix_searcher('mm')
         >>> objcpp = (f for f in os.listdir() where mmsuffix(f))
     """
-    if not suffix:
-        return true_function
-    search_function = re.compile(rf"{ex}{suffix.lstrip(ex)}",
-                                 re.IGNORECASE).search
-    return lambda searching_for: bool(search_function(searching_for))
+    return re_searcher(re_suffix(string))
 
 @export
 def swapext(path, new_extension):
@@ -92,6 +131,23 @@ def swapext(path, new_extension):
         return bulk
     return ex.join((bulk, new_extension.lstrip(ex)))
 
+@export
+def filesize(path):
+    """ Return the on-disk size (in bytes) of the file located at a path """
+    if not os.path.exists(path):
+        return -1
+    return os.lstat(path).st_size
+
+@export
+def samesize(path0, path1):
+    """ Compare the on-disk file sizes (in bytes) of two files by their paths """
+    from clu.constants.exceptions import FilesystemError
+    if any(p is None for p in (path0, path1)):
+        raise FilesystemError('paths must both be non-None')
+    if os.path.samefile(path0, path1):
+        return True
+    return filesize(path0) == filesize(path1)
+
 @export
 def u8encode(source):
     """ Encode a source as bytes using the UTF-8 codec """
@@ -146,6 +202,7 @@ def win32_longpath(path):
 
 octalize = lambda integer: "0o%04o" % integer
 
+@export
 @lru_cache(maxsize=1)
 def current_umask():
     """ Get the current umask value (cached on Python 3 and up). """
@@ -161,16 +218,19 @@ def masked_permissions(perms=0o666):
     return perms & ~current_umask()
 
 @export
-def masked_chmod(pth, perms=0o666):
+def masked_chmod(path, perms=0o666):
     """ Perform the `os.chmod(…)` operation, respecting the current
         umask value (q.v. `current_umask()` supra.)
     """
     masked_perms = masked_permissions(perms=perms)
-    os.chmod(pth, mode=masked_perms)
+    os.chmod(path, mode=masked_perms)
     return octalize(masked_perms)
 
 # MODULE EXPORTS:
-export(current_umask,           name='current_umask')
+export(re_matcher,              name='re_matcher')
+export(re_searcher,             name='re_searcher')
+
+export(gethomedir,              name='gethomedir',          doc="gethomedir() → Return the current user’s home directory")
 export(none_function,           name='none_function',       doc="none_function() → A function that always returns None")
 export(true_function,           name='true_function',       doc="true_function() → A function that always returns True")
 export(octalize,                name='octalize',            doc="octalize(integer) → Format an integer value as an octal number")
