@@ -219,9 +219,5 @@ def print_banner():
         else:
             print_warning(warning)
 
-# NO DOCS ALLOWED:
-export(banners,         name='banners')
-export(is_python2_dead, name='is_python2_dead')
-
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
